@@ -130,7 +130,7 @@ class OpenPR:
             if link:
                 pr_body = link + "\n\n"
             try:
-                with open("pull_request_template.md", "r") as f:
+                with open("pull_request_template.md", "r", encoding="utf-8") as f:
                     pr_body = pr_body + f.read() + "\n"
             except Exception:
                 pass
