@@ -53,6 +53,11 @@ class QA:
 
         self._qainit.user_info()
 
+    def _clean_date(self, datetime):
+        # expected format: '2021-07-23T14:04:12.000000Z'
+        datetime = datetime.split(".")[0]
+        return datetime.replace("T", " ")
+
     def _create_instance_table(self):
         instance_table = Table()
         instance_table.add_column("Name", style="purple")
@@ -61,6 +66,7 @@ class QA:
         instance_table.add_column("Created by", style="white")
         instance_table.add_column("Updated by", style="white")
         instance_table.add_column("Deleted by", style="white")
+        instance_table.add_column("Last update", style="white")
         instance_table.add_column("Status", style="white")
 
         return instance_table
@@ -79,6 +85,7 @@ class QA:
             qa.get("deleted", {}).get("github_username", "/")
             if qa["deleted"] is not None
             else "/",
+            self._clean_date(qa["updated_at"]),
             qa["status"],
         )
 
@@ -128,6 +135,7 @@ class QA:
             table.add_column("Microservice", style="purple", no_wrap=True)
             table.add_column("Drone build")
             table.add_column("Branch", style="white")
+            table.add_column("Last update", style="white")
             table.add_column("Status", style="white")
 
             # INSTANCE TABLE
@@ -146,19 +154,27 @@ class QA:
                 resources_list = sorted(r["list"]["resources"], key=lambda k: k["name"])
                 for resource in resources_list:
                     if (
-                        resource["type"] == "microservice"
-                        or "service" in resource["name"]
-                    ) and resource["dns"]:
+                        (
+                            resource["type"] == "microservice"
+                            or "service" in resource["name"]
+                        )
+                        and "dns" in resource
+                        and resource["dns"] is not None
+                    ):
                         for key, value in resource["dns"].items():
                             dns_table.add_row(key, value)
                     if resource["type"] == "microservice":
                         drone_url = (
-                            "[blue][u]"
-                            + "https://drone-1.prima.it/primait/"
-                            + resource["name"]
-                            + "/"
-                            + resource["promoted_build"]
-                            + "[/u][/blue]"
+                            (
+                                "[blue][u]"
+                                + "https://drone-1.prima.it/primait/"
+                                + resource["name"]
+                                + "/"
+                                + resource["promoted_build"]
+                                + "[/u][/blue]"
+                            )
+                            if resource["promoted_build"]
+                            else "Not available"
                         )
                         table.add_row(
                             resource["name"],
@@ -166,14 +182,15 @@ class QA:
                             resource["ref"]
                             if resource["ref"] == "master"
                             else f"[green]{resource['ref']}[/green]",
+                            self._clean_date(resource["updated_at"]),
                             resource["status"],
                         )
 
                 console.print(instance_table)
                 console.print(dns_table)
                 console.print(table)
-            except TypeError:
-                logger.error("Wrong hash")
+            except TypeError as e:
+                logger.error(f"Unexpected response format: {e}")
 
     def _delete(self):
         self._qainit.delete(self._flags["hash"])
