@@ -22,7 +22,7 @@ class Tokens:
             self.save()
 
     def load(self):
-        with open(self._file_name, "rb", encoding="utf-8") as configfile:
+        with open(self._file_name, "rb") as configfile:
             self._tokens = marshal.load(configfile)
 
     def check(self):
@@ -40,7 +40,7 @@ class Tokens:
                 self._changed = True
 
     def save(self):
-        with open(self._file_name, "wb", encoding="utf-8") as configfile:
+        with open(self._file_name, "wb") as configfile:
             marshal.dump(self._tokens, configfile)
 
     def edit(self, service, token):
